import{d as u,eB as b,H as m,a as f,b as g,c as v,w as s,f as i}from"./outputWidgets.ef7f3407.js";import{B as _}from"./BaseLayout.0bf732d1.js";import{a as h}from"./asyncComputed.352c228a.js";import"./router.bb5913c7.js";import"./index.e05ba064.js";import{P as y}from"./project.2db05882.js";import{O as w}from"./organization.34d46b4c.js";import{_ as z}from"./Navbar.vue_vue_type_script_setup_true_lang.9143ace3.js";import{S as I}from"./Sidebar.fc2c052a.js";import{e as j,R as C,S as O,T as k,U as B,v as S,H as L,V as N,W as P,N as x}from"./icons.c4e300ba.js";import"./Form.657b35f5.js";import"./hasIn.2b606bf1.js";import"./index.cf4c23b9.js";import"./record.2e6ff048.js";import"./pubsub.b4b207c2.js";import"./logo.084e5d7c.js";import"./Text.361a5f7a.js";import"./Base.00784e3c.js";import"./Typography.56b07efe.js";import"./index.b9710cc4.js";import"./ArrowRightOutlined.08fa31dd.js";import"./index.edf02e38.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="a063df0b-60cd-4fb7-b2dc-379089e24738",o._sentryDebugIdIdentifier="sentry-dbid-a063df0b-60cd-4fb7-b2dc-379089e24738")}catch{}})();const oe=u({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>y.get(c).then(async e=>{const t=await w.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),d=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:j},{name:"Builds",path:"builds",icon:C},{name:"Connectors",path:"connectors",icon:O,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:k},{name:"API Keys",path:"api-keys",icon:B},{name:"Env Vars",path:"env-vars",icon:S},{name:"Files",path:"files",icon:L},{name:"Logs",icon:N,path:"logs"},{name:"Settings",icon:P,path:"settings"},{name:"Users",icon:x,path:"users"}]}]:[]});return(e,t)=>{const n=f("router-view");return g(),v(_,null,{content:s(()=>[i(n)]),navbar:s(()=>[i(z,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:s(()=>[i(I,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{oe as default};
//# sourceMappingURL=Project.62720a4e.js.map
