import{u as s}from"./index.5ed874f5.js";import{d as c,b as d,ev as l,f as p,u as r}from"./outputWidgets.ef7f3407.js";import{g as f}from"./api.e8cea29c.js";import{K as u,L as b}from"./repository.a9851d04.js";import{_ as g}from"./Navbar.vue_vue_type_script_setup_true_lang.393630c4.js";import{a as y}from"./asyncComputed.352c228a.js";import{P as _}from"./repository.517e59cf.js";import"./pubsub.b4b207c2.js";import"./runnerData.7142dc1d.js";import"./url.d258a57b.js";import"./api.db4f0a0a.js";import"./index.cf4c23b9.js";import"./icons.c4e300ba.js";import"./ant-design.f3720243.js";import"./index.f158f070.js";import"./Modal.bf1b2b77.js";import"./Text.361a5f7a.js";import"./Base.00784e3c.js";import"./Typography.56b07efe.js";import"./index.3db3a5f6.js";import"./Link.574ee8b3.js";import"./Paragraph.7f2d959b.js";import"./Title.1adff754.js";import"./index.030a4369.js";import"./index.edf02e38.js";import"./index.a41f195f.js";import"./index.29ac8d6b.js";import"./CollapsePanel.cff0c182.js";import"./Form.657b35f5.js";import"./hasIn.2b606bf1.js";import"./Timeline.11f7bdd3.js";import"./index.8ed8081b.js";import"./index.51110c94.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.ae70e7eb.js";import"./workspaces.9e93225b.js";import"./record.2e6ff048.js";import"./scripts.a1a413b6.js";import"./envVars.42f74dcb.js";import"./ExpandOutlined.8020b32e.js";import"./Card.60565ea4.js";import"./TabPane.7712efbf.js";import"./index.b9710cc4.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="23aa1525-dec9-48e5-9a7c-4aa6ca509ca1",o._sentryDebugIdIdentifier="sentry-dbid-23aa1525-dec9-48e5-9a7c-4aa6ca509ca1")}catch{}})();const lo=c({__name:"Kanban",setup(o){const t=new _(s),e=new b("kanban"),{result:a}=y(f);return(k,w)=>{var i,m,n;return d(),l("div",null,[p(g,{"brand-name":((i=r(a))==null?void 0:i.brandName)||((m=r(a))==null?void 0:m.name),"logo-url":(n=r(a))==null?void 0:n.logoUrl},null,8,["brand-name","logo-url"]),p(u,{"kanban-repository":r(t),storage:r(e)},null,8,["kanban-repository","storage"])])}}});export{lo as default};
//# sourceMappingURL=Kanban.43ca7364.js.map
