import{r,w as a}from"./runnerData.7142dc1d.js";import"./outputWidgets.ef7f3407.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="3f06441b-3dbb-4aa1-a585-1590249760b0",t._sentryDebugIdIdentifier="sentry-dbid-3f06441b-3dbb-4aa1-a585-1590249760b0")}catch{}})();async function f(t){const e=await fetch(`/_pages/${t}`);if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:n}=await e.json();return n?r(n):null}async function u(){const t=await fetch("/_workspace");if(t.status!=200)return a({});const e=await t.json();return a(e)}export{f,u as g};
//# sourceMappingURL=api.e8cea29c.js.map
