import"./outputWidgets.ef7f3407.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="91a7434e-13d3-43ed-8948-8721fe02249f",e._sentryDebugIdIdentifier="sentry-dbid-91a7434e-13d3-43ed-8948-8721fe02249f")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.d258a57b.js.map
