import{cz as a}from"./outputWidgets.ef7f3407.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="aaaeabf6-c0df-46a2-a5bd-73d7cf38b8ad",e._sentryDebugIdIdentifier="sentry-dbid-aaaeabf6-c0df-46a2-a5bd-73d7cf38b8ad")}catch{}})();const f=(e,d)=>{a.error({message:e,description:d})};export{f as p};
//# sourceMappingURL=popupNotifcation.875b663f.js.map
