import{B as s}from"./Base.00784e3c.js";import{A as o}from"./Link.574ee8b3.js";import{A as a}from"./Paragraph.7f2d959b.js";import{A as r}from"./Text.361a5f7a.js";import{A as i}from"./Title.1adff754.js";import{T as e}from"./Typography.56b07efe.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="89902d92-c002-481a-8c43-911a942b6114",n._sentryDebugIdIdentifier="sentry-dbid-89902d92-c002-481a-8c43-911a942b6114")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=a;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,a),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.3db3a5f6.js.map
