import{eQ as t,eR as r}from"./outputWidgets.ef7f3407.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="de9b511f-e245-4dbc-829c-00b841b50afa",e._sentryDebugIdIdentifier="sentry-dbid-de9b511f-e245-4dbc-829c-00b841b50afa")}catch{}})();function a(e,n){return t(1,arguments),r(e,Date.now(),n)}export{a as f};
//# sourceMappingURL=index.a41f195f.js.map
