import{K as n,L as a}from"./repository.a9851d04.js";import{E as p}from"./repository.517e59cf.js";import{d as s,b as m,c,u as i}from"./outputWidgets.ef7f3407.js";import{l as f}from"./index.5ed874f5.js";import"./asyncComputed.352c228a.js";import"./api.db4f0a0a.js";import"./index.cf4c23b9.js";import"./icons.c4e300ba.js";import"./ant-design.f3720243.js";import"./index.f158f070.js";import"./Modal.bf1b2b77.js";import"./Text.361a5f7a.js";import"./Base.00784e3c.js";import"./Typography.56b07efe.js";import"./index.3db3a5f6.js";import"./Link.574ee8b3.js";import"./Paragraph.7f2d959b.js";import"./Title.1adff754.js";import"./index.030a4369.js";import"./index.edf02e38.js";import"./index.a41f195f.js";import"./index.29ac8d6b.js";import"./CollapsePanel.cff0c182.js";import"./Form.657b35f5.js";import"./hasIn.2b606bf1.js";import"./Timeline.11f7bdd3.js";import"./index.8ed8081b.js";import"./index.51110c94.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.ae70e7eb.js";import"./workspaces.9e93225b.js";import"./runnerData.7142dc1d.js";import"./url.d258a57b.js";import"./record.2e6ff048.js";import"./pubsub.b4b207c2.js";import"./scripts.a1a413b6.js";import"./envVars.42f74dcb.js";import"./ExpandOutlined.8020b32e.js";import"./Card.60565ea4.js";import"./TabPane.7712efbf.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="2daf7a40-ac18-4281-acc0-484521a046f1",t._sentryDebugIdIdentifier="sentry-dbid-2daf7a40-ac18-4281-acc0-484521a046f1")}catch{}})();class d{constructor(o=f){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const to=s({__name:"WorkflowKanban",setup(t){const o=new p,r=new d,e=new a("kanban");return(u,y)=>(m(),c(n,{"kanban-repository":i(o),storage:i(e),"stage-run-repository":i(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{to as default};
//# sourceMappingURL=WorkflowKanban.3c56b390.js.map
