import{ac as f,V as t,Q as a,f as p}from"./outputWidgets.ef7f3407.js";import{B as l,b}from"./Base.00784e3c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="025f55b3-6449-40ee-9b31-dde8657bf028",e._sentryDebugIdIdentifier="sentry-dbid-025f55b3-6449-40ee-9b31-dde8657bf028")}catch{}})();const c=()=>t(t({},a(b(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:r,attrs:d}=s;const{ellipsis:n}=e;f();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?a(n,["expandable","rows"]):n,component:"span"}),d);return p(l,i,r)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=c();const g=o;export{g as A};
//# sourceMappingURL=Text.361a5f7a.js.map
