import{C as t,A as m}from"./CollapsePanel.cff0c182.js";import{F as n}from"./Form.657b35f5.js";import{aM as i,co as r}from"./outputWidgets.ef7f3407.js";import{T as o,A as a}from"./Timeline.11f7bdd3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="34a54ba7-7453-43a5-8dec-e993d72fae97",e._sentryDebugIdIdentifier="sentry-dbid-34a54ba7-7453-43a5-8dec-e993d72fae97")}catch{}})();t.Panel=m;t.install=function(e){return e.component(t.name,t),e.component(m.name,m),e};n.useInjectFormItemContext=i;n.ItemRest=r;n.install=function(e){return e.component(n.name,n),e.component(n.Item.name,n.Item),e.component(r.name,r),e};o.Item=a;o.install=function(e){return e.component(o.name,o),e.component(a.name,a),e};
//# sourceMappingURL=index.29ac8d6b.js.map
