import{g as m}from"./api.e8cea29c.js";import{P as c}from"./Passwordless.f7bde46c.js";import{a as f}from"./asyncComputed.352c228a.js";import{W as p}from"./WidgetsFrame.6dcbe6ca.js";import{d as u,eA as l,eB as _,b as d,ev as y,e as g,u as s,c as h,w,ex as b,f as v,v as k}from"./outputWidgets.ef7f3407.js";import"./runnerData.7142dc1d.js";import"./url.d258a57b.js";import"./index.5ed874f5.js";import"./pubsub.b4b207c2.js";import"./icons.c4e300ba.js";import"./CircularLoading.95908b2d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="df269423-1606-473e-8d22-e11635fd93e2",e._sentryDebugIdIdentifier="sentry-dbid-df269423-1606-473e-8d22-e11635fd93e2")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),r=_(),{result:o}=f(m),i=()=>{const{redirect:a,...n}=r.query;if(a){t.push({path:a,query:n,params:r.params});return}t.push({name:"playerKanban",query:n})};return(a,n)=>(d(),y("div",null,[g("div",x,[s(o)?(d(),h(p,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:w(()=>[v(c,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):b("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.2f17a7cf.js.map
