import{V as s,f as d,Q as p}from"./outputWidgets.ef7f3407.js";import{B as c,b as f}from"./Base.00784e3c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4428d3ee-c2ca-4e4c-af35-194addbbc486",e._sentryDebugIdIdentifier="sentry-dbid-4428d3ee-c2ca-4e4c-af35-194addbbc486")}catch{}})();const i=()=>p(f(),["component"]),r=(e,a)=>{let{slots:t,attrs:o}=a;const n=s(s(s({},e),{component:"div"}),o);return d(c,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=i();const g=r;export{g as A};
//# sourceMappingURL=Paragraph.7f2d959b.js.map
